
.. _api:

Low-level API
=============

Carton
------

.. automodule:: target_selection.cartons.base
   :members: BaseCarton
   :undoc-members:
   :show-inheritance:

.. automodule:: target_selection.cartons.tools
   :members: get_file_carton
   :undoc-members:
   :show-inheritance:

.. _api-xmatch:

XMatch
------

.. automodule:: target_selection.xmatch
   :members: XMatchModel, XMatchPlanner, RUN_ID_BIT_SHIFT

Skies
-----

.. automodule:: target_selection.skies
   :members: get_sky_table, nested_regrade, plot_sky_density, plot_skies

Utils
-----

.. automodule:: target_selection.utils
   :members:
